@@ -26,9 +26,9 @@ use crate::{
     utils::*,
     validity_period, AddPrefix, PrefixConfiguration, Result,
 };
+use anyhow::{anyhow, Context};
 use chrono_tz::Tz;
 use derivative::Derivative;
-use failure::ResultExt;
 use serde::{Deserialize, Serialize};
 use std::{collections::BTreeMap, fmt, path::Path};
 use tracing::info;
@@ -401,13 +401,13 @@ impl Reader {
             // if it's a file, we consider it to be a zip (and an error will be returned if it is not)
             Ok(self
                 .parse_zip(p)
-                .with_context(|_| format!("impossible to read zipped gtfs {:?}", p))?)
+                .with_context(|| format!("impossible to read zipped gtfs {:?}", p))?)
         } else if p.is_dir() {
             Ok(self
                 .parse_dir(p)
-                .with_context(|_| format!("impossible to read gtfs directory from {:?}", p))?)
+                .with_context(|| format!("impossible to read gtfs directory from {:?}", p))?)
         } else {
-            Err(failure::format_err!(
+            Err(anyhow!(
                 "file {:?} is neither a file nor a directory, cannot read a gtfs from it",
                 p
             ))
