@@ -21,7 +21,7 @@ use crate::objects;
 use crate::objects::Transfer as NtfsTransfer;
 use crate::objects::*;
 use crate::Result;
-use failure::ResultExt;
+use anyhow::Context;
 use geo::Geometry as GeoGeometry;
 use relational_types::IdxSet;
 use serde::{Deserialize, Serialize};
@@ -37,16 +37,16 @@ pub fn write_transfers(path: &path::Path, transfers: &Collection<NtfsTransfer>)
     info!("Writing transfers.txt");
     let path = path.join("transfers.txt");
     let mut wtr =
-        csv::Writer::from_path(&path).with_context(|_| format!("Error reading {:?}", path))?;
+        csv::Writer::from_path(&path).with_context(|| format!("Error reading {:?}", path))?;
     for t in transfers.values() {
         if t.from_stop_id != t.to_stop_id {
             wtr.serialize(Transfer::from(t))
-                .with_context(|_| format!("Error reading {:?}", path))?;
+                .with_context(|| format!("Error reading {:?}", path))?;
         }
     }
 
     wtr.flush()
-        .with_context(|_| format!("Error reading {:?}", path))?;
+        .with_context(|| format!("Error reading {:?}", path))?;
 
     Ok(())
 }
@@ -58,14 +58,14 @@ pub fn write_agencies(
     info!("Writing agency.txt");
     let path = path.join("agency.txt");
     let mut wtr =
-        csv::Writer::from_path(&path).with_context(|_| format!("Error reading {:?}", path))?;
+        csv::Writer::from_path(&path).with_context(|| format!("Error reading {:?}", path))?;
     for n in networks.values() {
         wtr.serialize(Agency::from(n))
-            .with_context(|_| format!("Error reading {:?}", path))?;
+            .with_context(|| format!("Error reading {:?}", path))?;
     }
 
     wtr.flush()
-        .with_context(|_| format!("Error reading {:?}", path))?;
+        .with_context(|| format!("Error reading {:?}", path))?;
 
     Ok(())
 }
@@ -184,25 +184,25 @@ pub fn write_stops(
     info!("Writing {}", file);
     let path = path.join(file);
     let mut wtr =
-        csv::Writer::from_path(&path).with_context(|_| format!("Error reading {:?}", path))?;
+        csv::Writer::from_path(&path).with_context(|| format!("Error reading {:?}", path))?;
     info!("Writing {} from StopPoint", file);
     for sp in stop_points.values() {
         wtr.serialize(ntfs_stop_point_to_gtfs_stop(sp, comments, equipments))
-            .with_context(|_| format!("Error reading {:?}", path))?;
+            .with_context(|| format!("Error reading {:?}", path))?;
     }
     info!("Writing {} from StopArea", file);
     for sa in stop_areas.values() {
         wtr.serialize(ntfs_stop_area_to_gtfs_stop(sa, comments, equipments))
-            .with_context(|_| format!("Error reading {:?}", path))?;
+            .with_context(|| format!("Error reading {:?}", path))?;
     }
     info!("Writing {} from StopLocation", file);
     for sl in stop_locations.values() {
         wtr.serialize(ntfs_stop_location_to_gtfs_stop(sl, comments, equipments))
-            .with_context(|_| format!("Error reading {:?}", path))?;
+            .with_context(|| format!("Error reading {:?}", path))?;
     }
 
     wtr.flush()
-        .with_context(|_| format!("Error reading {:?}", path))?;
+        .with_context(|| format!("Error reading {:?}", path))?;
 
     Ok(())
 }
@@ -247,14 +247,14 @@ pub fn write_trips(path: &path::Path, model: &Model) -> Result<()> {
     info!("Writing trips.txt");
     let path = path.join("trips.txt");
     let mut wtr =
-        csv::Writer::from_path(&path).with_context(|_| format!("Error reading {:?}", path))?;
+        csv::Writer::from_path(&path).with_context(|| format!("Error reading {:?}", path))?;
     for vj in model.vehicle_journeys.values() {
         wtr.serialize(make_gtfs_trip_from_ntfs_vj(vj, model))
-            .with_context(|_| format!("Error reading {:?}", path))?;
+            .with_context(|| format!("Error reading {:?}", path))?;
     }
 
     wtr.flush()
-        .with_context(|_| format!("Error reading {:?}", path))?;
+        .with_context(|| format!("Error reading {:?}", path))?;
 
     Ok(())
 }
@@ -298,13 +298,13 @@ pub fn write_stop_extensions(
     info!("Writing stop_extensions.txt");
     let path = path.join("stop_extensions.txt");
     let mut wtr =
-        csv::Writer::from_path(&path).with_context(|_| format!("Error reading {:?}", path))?;
+        csv::Writer::from_path(&path).with_context(|| format!("Error reading {:?}", path))?;
     for se in stop_extensions {
         wtr.serialize(se)
-            .with_context(|_| format!("Error reading {:?}", path))?;
+            .with_context(|| format!("Error reading {:?}", path))?;
     }
     wtr.flush()
-        .with_context(|_| format!("Error reading {:?}", path))?;
+        .with_context(|| format!("Error reading {:?}", path))?;
 
     Ok(())
 }
@@ -401,16 +401,16 @@ pub fn write_routes(path: &path::Path, model: &Model) -> Result<()> {
     info!("Writing routes.txt");
     let path = path.join("routes.txt");
     let mut wtr =
-        csv::Writer::from_path(&path).with_context(|_| format!("Error reading {:?}", path))?;
+        csv::Writer::from_path(&path).with_context(|| format!("Error reading {:?}", path))?;
     for (from, l) in &model.lines {
         for pm in &get_line_physical_modes(from, &model.physical_modes, model) {
             wtr.serialize(make_gtfs_route_from_ntfs_line(l, pm))
-                .with_context(|_| format!("Error reading {:?}", path))?;
+                .with_context(|| format!("Error reading {:?}", path))?;
         }
     }
 
     wtr.flush()
-        .with_context(|_| format!("Error reading {:?}", path))?;
+        .with_context(|| format!("Error reading {:?}", path))?;
 
     Ok(())
 }
@@ -424,7 +424,7 @@ pub fn write_stop_times(
     info!("Writing stop_times.txt");
     let stop_times_path = path.join("stop_times.txt");
     let mut st_wtr = csv::Writer::from_path(&stop_times_path)
-        .with_context(|_| format!("Error reading {:?}", stop_times_path))?;
+        .with_context(|| format!("Error reading {:?}", stop_times_path))?;
     for (vj_idx, vj) in vehicle_journeys {
         for st in &vj.stop_times {
             st_wtr
@@ -442,12 +442,12 @@ pub fn write_stop_times(
                         .cloned(),
                     timepoint: !st.datetime_estimated,
                 })
-                .with_context(|_| format!("Error reading {:?}", st_wtr))?;
+                .with_context(|| format!("Error reading {:?}", st_wtr))?;
         }
     }
     st_wtr
         .flush()
-        .with_context(|_| format!("Error reading {:?}", stop_times_path))?;
+        .with_context(|| format!("Error reading {:?}", stop_times_path))?;
     Ok(())
 }
 
@@ -483,12 +483,12 @@ pub fn write_shapes(
         info!("Writing shapes.txt");
         let path = path.join("shapes.txt");
         let mut wtr =
-            csv::Writer::from_path(&path).with_context(|_| format!("Error reading {:?}", path))?;
+            csv::Writer::from_path(&path).with_context(|| format!("Error reading {:?}", path))?;
         wtr.flush()
-            .with_context(|_| format!("Error reading {:?}", path))?;
+            .with_context(|| format!("Error reading {:?}", path))?;
         for shape in shapes {
             wtr.serialize(shape)
-                .with_context(|_| format!("Error reading {:?}", path))?;
+                .with_context(|| format!("Error reading {:?}", path))?;
         }
     }
 
