@@ -17,9 +17,9 @@ use crate::model::Collections;
 use crate::ntfs::{has_fares_v1, has_fares_v2};
 use crate::objects::*;
 use crate::NTFS_VERSION;
+use anyhow::{anyhow, bail, Context};
 use chrono::{DateTime, Duration, FixedOffset};
 use csv::Writer;
-use failure::{bail, format_err, ResultExt};
 use rust_decimal::{prelude::ToPrimitive, Decimal};
 use std::collections::{BTreeSet, HashMap};
 use std::fs::File;
@@ -59,15 +59,15 @@ pub fn write_feed_infos(
     );
 
     let mut wtr =
-        csv::Writer::from_path(&path).with_context(|_| format!("Error reading {:?}", path))?;
+        csv::Writer::from_path(&path).with_context(|| format!("Error reading {:?}", path))?;
     wtr.write_record(&["feed_info_param", "feed_info_value"])
-        .with_context(|_| format!("Error reading {:?}", path))?;
+        .with_context(|| format!("Error reading {:?}", path))?;
     for feed_info in feed_infos {
         wtr.serialize(feed_info)
-            .with_context(|_| format!("Error reading {:?}", path))?;
+            .with_context(|| format!("Error reading {:?}", path))?;
     }
     wtr.flush()
-        .with_context(|_| format!("Error reading {:?}", path))?;
+        .with_context(|| format!("Error reading {:?}", path))?;
     Ok(())
 }
 
@@ -82,13 +82,13 @@ pub fn write_vehicle_journeys_and_stop_times(
     let trip_path = path.join("trips.txt");
     let stop_times_path = path.join("stop_times.txt");
     let mut vj_wtr = csv::Writer::from_path(&trip_path)
-        .with_context(|_| format!("Error reading {:?}", trip_path))?;
+        .with_context(|| format!("Error reading {:?}", trip_path))?;
     let mut st_wtr = csv::Writer::from_path(&stop_times_path)
-        .with_context(|_| format!("Error reading {:?}", stop_times_path))?;
+        .with_context(|| format!("Error reading {:?}", stop_times_path))?;
     for (vj_idx, vj) in vehicle_journeys.iter() {
         vj_wtr
             .serialize(vj)
-            .with_context(|_| format!("Error reading {:?}", trip_path))?;
+            .with_context(|| format!("Error reading {:?}", trip_path))?;
 
         for st in &vj.stop_times {
             let precision = st.precision.clone().or_else(|| {
@@ -119,15 +119,15 @@ pub fn write_vehicle_journeys_and_stop_times(
                         .cloned(),
                     precision,
                 })
-                .with_context(|_| format!("Error reading {:?}", st_wtr))?;
+                .with_context(|| format!("Error reading {:?}", st_wtr))?;
         }
     }
     st_wtr
         .flush()
-        .with_context(|_| format!("Error reading {:?}", stop_times_path))?;
+        .with_context(|| format!("Error reading {:?}", stop_times_path))?;
     vj_wtr
         .flush()
-        .with_context(|_| format!("Error reading {:?}", trip_path))?;
+        .with_context(|| format!("Error reading {:?}", trip_path))?;
 
     Ok(())
 }
@@ -150,15 +150,15 @@ fn do_write_fares_v1(
     let path = base_path.join(file_prices);
     let mut prices_wtr = builder
         .from_path(&path)
-        .with_context(|_| format!("Error reading {:?}", path))?;
+        .with_context(|| format!("Error reading {:?}", path))?;
     for price_v1 in prices_v1.values() {
         prices_wtr
             .serialize(price_v1)
-            .with_context(|_| format!("Error reading {:?}", path))?;
+            .with_context(|| format!("Error reading {:?}", path))?;
     }
     prices_wtr
         .flush()
-        .with_context(|_| format!("Error reading {:?}", path))?;
+        .with_context(|| format!("Error reading {:?}", path))?;
 
     builder.has_headers(true);
 
@@ -166,11 +166,11 @@ fn do_write_fares_v1(
     let path = base_path.join(file_od_fares);
     let mut od_fares_wtr = builder
         .from_path(&path)
-        .with_context(|_| format!("Error reading {:?}", path))?;
+        .with_context(|| format!("Error reading {:?}", path))?;
     for od_fare_v1 in od_fares_v1.values() {
         od_fares_wtr
             .serialize(od_fare_v1)
-            .with_context(|_| format!("Error reading {:?}", path))?;
+            .with_context(|| format!("Error reading {:?}", path))?;
     }
     // Write file header if collection is empty (normally done by serialize)
     if od_fares_v1.is_empty() {
@@ -186,7 +186,7 @@ fn do_write_fares_v1(
     }
     od_fares_wtr
         .flush()
-        .with_context(|_| format!("Error reading {:?}", path))?;
+        .with_context(|| format!("Error reading {:?}", path))?;
 
     if fares_v1.is_empty() {
         info!("Writing skipped {}", file_fares);
@@ -197,15 +197,15 @@ fn do_write_fares_v1(
     let path = base_path.join(file_fares);
     let mut fares_wtr = builder
         .from_path(&path)
-        .with_context(|_| format!("Error reading {:?}", path))?;
+        .with_context(|| format!("Error reading {:?}", path))?;
     for fare_v1 in fares_v1.values() {
         fares_wtr
             .serialize(fare_v1)
-            .with_context(|_| format!("Error reading {:?}", path))?;
+            .with_context(|| format!("Error reading {:?}", path))?;
     }
     fares_wtr
         .flush()
-        .with_context(|_| format!("Error reading {:?}", path))?;
+        .with_context(|| format!("Error reading {:?}", path))?;
 
     Ok(())
 }
@@ -272,7 +272,7 @@ fn build_price_v1(id: &str, ticket: &Ticket, price: &TicketPrice) -> Result<Pric
     let cents_price = cents_price
         .round_dp(0)
         .to_u32()
-        .ok_or_else(|| format_err!("Cannot convert price {:?} into a u32", cents_price))?;
+        .ok_or_else(|| anyhow!("Cannot convert price {:?} into a u32", cents_price))?;
     let comment = ticket.comment.clone().unwrap_or_else(String::new);
     let price_v1 = PriceV1 {
         id: id.to_string(),
@@ -318,7 +318,7 @@ fn construct_fare_v1_from_v2(fares: &Fares) -> Result<(BTreeSet<PriceV1>, BTreeS
         //  there cannot exists two Ticket with the same ticket_id in fares.tickets
         //  thus it is sufficient to check if one ticket exists with the requested ticket_id
         let ticket = fares.tickets.get(&ticket_use.ticket_id).ok_or_else(|| {
-            format_err!(
+            anyhow!(
                 "The ticket_id {:?} was not found in tickets.txt",
                 ticket_use.ticket_id
             )
@@ -558,7 +558,7 @@ pub fn write_stops(
     info!("Writing {}", file);
     let path = path.join(file);
     let mut wtr =
-        csv::Writer::from_path(&path).with_context(|_| format!("Error reading {:?}", path))?;
+        csv::Writer::from_path(&path).with_context(|| format!("Error reading {:?}", path))?;
     for st in stop_points.values() {
         let location_type = if st.stop_type == StopType::Zone {
             StopLocationType::GeographicArea
@@ -582,7 +582,7 @@ pub fn write_stops(
             platform_code: st.platform_code.clone(),
             address_id: st.address_id.clone(),
         })
-        .with_context(|_| format!("Error reading {:?}", path))?;
+        .with_context(|| format!("Error reading {:?}", path))?;
     }
 
     for sa in stop_areas.values() {
@@ -603,12 +603,12 @@ pub fn write_stops(
             platform_code: None,
             address_id: None,
         })
-        .with_context(|_| format!("Error reading {:?}", path))?;
+        .with_context(|| format!("Error reading {:?}", path))?;
     }
     write_stop_locations(&mut wtr, stop_locations)
-        .with_context(|_| format!("Error reading {:?}", path))?;
+        .with_context(|| format!("Error reading {:?}", path))?;
     wtr.flush()
-        .with_context(|_| format!("Error reading {:?}", path))?;
+        .with_context(|| format!("Error reading {:?}", path))?;
 
     Ok(())
 }
@@ -629,7 +629,7 @@ where
                 object_type: T::get_object_type(),
                 comment_id: comment_id.to_string(),
             })
-            .with_context(|_| format!("Error reading {:?}", path))?;
+            .with_context(|| format!("Error reading {:?}", path))?;
         }
     }
 
@@ -653,7 +653,7 @@ where
             object_type: ObjectType::StopTime,
             comment_id: id_comment.to_string(),
         })
-        .with_context(|_| format!("Error reading {:?}", path))?;
+        .with_context(|| format!("Error reading {:?}", path))?;
     }
 
     Ok(())
@@ -669,13 +669,13 @@ pub fn write_comments(path: &path::Path, collections: &Collections) -> Result<()
     let comment_links_path = path.join("comment_links.txt");
 
     let mut c_wtr = csv::Writer::from_path(&comments_path)
-        .with_context(|_| format!("Error reading {:?}", comments_path))?;
+        .with_context(|| format!("Error reading {:?}", comments_path))?;
     let mut cl_wtr = csv::Writer::from_path(&comment_links_path)
-        .with_context(|_| format!("Error reading {:?}", comment_links_path))?;
+        .with_context(|| format!("Error reading {:?}", comment_links_path))?;
     for c in collections.comments.values() {
         c_wtr
             .serialize(c)
-            .with_context(|_| format!("Error reading {:?}", comments_path))?;
+            .with_context(|| format!("Error reading {:?}", comments_path))?;
     }
 
     write_comment_links_from_collection_with_id(
@@ -715,10 +715,10 @@ pub fn write_comments(path: &path::Path, collections: &Collections) -> Result<()
 
     cl_wtr
         .flush()
-        .with_context(|_| format!("Error reading {:?}", comment_links_path))?;
+        .with_context(|| format!("Error reading {:?}", comment_links_path))?;
     c_wtr
         .flush()
-        .with_context(|_| format!("Error reading {:?}", comments_path))?;
+        .with_context(|| format!("Error reading {:?}", comments_path))?;
 
     Ok(())
 }
@@ -740,7 +740,7 @@ where
                 object_system: c.0.clone(),
                 object_code: c.1.clone(),
             })
-            .with_context(|_| format!("Error reading {:?}", path))?;
+            .with_context(|| format!("Error reading {:?}", path))?;
         }
     }
 
@@ -767,7 +767,7 @@ pub fn write_codes(path: &path::Path, collections: &Collections) -> Result<()> {
     let path = path.join("object_codes.txt");
 
     let mut wtr =
-        csv::Writer::from_path(&path).with_context(|_| format!("Error reading {:?}", path))?;
+        csv::Writer::from_path(&path).with_context(|| format!("Error reading {:?}", path))?;
     write_codes_from_collection_with_id(&mut wtr, &collections.stop_areas, &path)?;
     write_codes_from_collection_with_id(&mut wtr, &collections.stop_points, &path)?;
     write_codes_from_collection_with_id(&mut wtr, &collections.networks, &path)?;
@@ -777,7 +777,7 @@ pub fn write_codes(path: &path::Path, collections: &Collections) -> Result<()> {
     write_codes_from_collection_with_id(&mut wtr, &collections.companies, &path)?;
 
     wtr.flush()
-        .with_context(|_| format!("Error reading {:?}", path))?;
+        .with_context(|| format!("Error reading {:?}", path))?;
 
     Ok(())
 }
@@ -799,7 +799,7 @@ where
                 object_property_name: c.0.clone(),
                 object_property_value: c.1.clone(),
             })
-            .with_context(|_| format!("Error reading {:?}", path))?;
+            .with_context(|| format!("Error reading {:?}", path))?;
         }
     }
 
@@ -826,7 +826,7 @@ pub fn write_object_properties(path: &path::Path, collections: &Collections) ->
     let path = path.join("object_properties.txt");
 
     let mut wtr =
-        csv::Writer::from_path(&path).with_context(|_| format!("Error reading {:?}", path))?;
+        csv::Writer::from_path(&path).with_context(|| format!("Error reading {:?}", path))?;
     write_object_properties_from_collection_with_id(&mut wtr, &collections.stop_areas, &path)?;
     write_object_properties_from_collection_with_id(&mut wtr, &collections.stop_points, &path)?;
     write_object_properties_from_collection_with_id(&mut wtr, &collections.lines, &path)?;
@@ -838,7 +838,7 @@ pub fn write_object_properties(path: &path::Path, collections: &Collections) ->
     )?;
 
     wtr.flush()
-        .with_context(|_| format!("Error reading {:?}", path))?;
+        .with_context(|| format!("Error reading {:?}", path))?;
 
     Ok(())
 }
